@@ -10,6 +10,7 @@ use {
             GossipVerifiedVoteHashSender, VerifiedVoteSender, VoteTracker,
         },
         fetch_stage::FetchStage,
+        find_packet_sender_stake_stage::FindPacketSenderStakeStage,
         sigverify::TransactionSigVerifier,
         sigverify_stage::SigVerifyStage,
     },
@@ -55,6 +56,8 @@ pub struct Tpu {
     cluster_info_vote_listener: ClusterInfoVoteListener,
     broadcast_stage: BroadcastStage,
     tpu_quic_t: thread::JoinHandle<()>,
+    find_packet_sender_stake_stage: FindPacketSenderStakeStage,
+    vote_find_packet_sender_stake_stage: FindPacketSenderStakeStage,
 }
 
 impl Tpu {
@@ -103,6 +106,26 @@ impl Tpu {
             poh_recorder,
             tpu_coalesce_ms,
         );
+
+        let (find_packet_sender_stake_sender, find_packet_sender_stake_receiver) = unbounded();
+
+        let find_packet_sender_stake_stage = FindPacketSenderStakeStage::new(
+            packet_receiver,
+            find_packet_sender_stake_sender,
+            bank_forks.clone(),
+            cluster_info.clone(),
+        );
+
+        let (vote_find_packet_sender_stake_sender, vote_find_packet_sender_stake_receiver) =
+            unbounded();
+
+        let vote_find_packet_sender_stake_stage = FindPacketSenderStakeStage::new(
+            vote_packet_receiver,
+            vote_find_packet_sender_stake_sender,
+            bank_forks.clone(),
+            cluster_info.clone(),
+        );
+
         let (verified_sender, verified_receiver) = unbounded();
 
         let tpu_quic_t = solana_streamer::quic::spawn_server(
@@ -117,7 +140,7 @@ impl Tpu {
 
         let sigverify_stage = {
             let verifier = TransactionSigVerifier::default();
-            SigVerifyStage::new(packet_receiver, verified_sender, verifier)
+            SigVerifyStage::new(find_packet_sender_stake_receiver, verified_sender, verifier)
         };
 
         let (verified_tpu_vote_packets_sender, verified_tpu_vote_packets_receiver) = unbounded();
@@ -125,7 +148,7 @@ impl Tpu {
         let vote_sigverify_stage = {
             let verifier = TransactionSigVerifier::new_reject_non_vote();
             SigVerifyStage::new(
-                vote_packet_receiver,
+                vote_find_packet_sender_stake_receiver,
                 verified_tpu_vote_packets_sender,
                 verifier,
             )
@@ -179,6 +202,8 @@ impl Tpu {
             cluster_info_vote_listener,
             broadcast_stage,
             tpu_quic_t,
+            find_packet_sender_stake_stage,
+            vote_find_packet_sender_stake_stage,
         }
     }
 
@@ -189,6 +214,8 @@ impl Tpu {
             self.vote_sigverify_stage.join(),
             self.cluster_info_vote_listener.join(),
             self.banking_stage.join(),
+            self.find_packet_sender_stake_stage.join(),
+            self.vote_find_packet_sender_stake_stage.join(),
         ];
         self.tpu_quic_t.join()?;
         let broadcast_result = self.broadcast_stage.join();
